<?php
use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) {
    exit;
}

class RedPay extends PaymentModule
{
	private $_postErrors = array();

    public function __construct()
    {
        $this->name = 'redpay';
        $this->tab = 'payments_gateways';
        $this->version = '1.0.0';
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        $this->author = 'RedPay';
        $this->controllers = array('validation');
        $this->is_eu_compatible = 1;

        $this->currencies = true;
        $this->currencies_mode = 'checkbox';

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('RedPay');
        $this->description = $this->l('RedPay Payment Gateway');

        if (!count(Currency::checkPaymentCurrencies($this->id))) {
            $this->warning = $this->l('No currency has been set for this module.');
        }
    }

    public function install()
    {
        if (!parent::install() || !$this->registerHook('paymentOptions') || !$this->registerHook('paymentReturn')) {
            return false;
        }
        return true;
    }

    public function hookPaymentOptions($params)
    {
        if (!$this->active) {
            return;
        }

        if (!$this->checkCurrency($params['cart'])) {
            return;
        }

        $payment_options = [
            $this->getEmbeddedPaymentOption(),
        ];

        return $payment_options;
    }

    public function checkCurrency($cart)
    {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);

        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }
        return false;
    }

    public function getEmbeddedPaymentOption()
    {
        $embeddedOption = new PaymentOption();
        $embeddedOption->setCallToActionText('RedPay Tarjeta de Crdito')
						->setAdditionalInformation($this->context->smarty->fetch('module:redpay/views/templates/front/payment_infos.tpl'))
                       ->setForm($this->generateForm())
                       ->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/payment.png'));

        return $embeddedOption;
    }

    protected function generateForm()
    {
        $months = [];
        for ($i = 1; $i <= 12; $i++) {
            $months[] = sprintf("%02d", $i);
        }

        $years = [];
        for ($i = 0; $i <= 10; $i++) {
            $years[] = date('Y', strtotime('+'.$i.' years'));
        }

        $this->context->smarty->assign([
            'action' => $this->context->link->getModuleLink($this->name, 'validation', array(), true),
            'months' => $months,
            'years' => $years,
        ]);

        return $this->context->smarty->fetch('module:redpay/views/templates/front/payment_form.tpl');
    }
    /**
     * Returns a string containing the HTML necessary to
     * generate a configuration screen on the admin
     *
     * @return string
     */
    public function getContent()
    {
		$output = null;

		if (Tools::isSubmit('submit'.$this->name)) {
			$myModuleName = strval(Tools::getValue('ApiKey'));
			$myPassword = strval(Tools::getValue('Password'));
			$myAmbiente = strval(Tools::getValue('Ambiente'));
			if (
				!$myModuleName ||
				empty($myModuleName) ||
				!Validate::isGenericName($myModuleName)
			) {
				$output .= $this->displayError('ApiKey es requerido');
			} else if (
				!$myPassword ||
				empty($myPassword) ||
				!Validate::isGenericName($myPassword)
			) {
				$output .= $this->displayError('Password es requerido');
			} else if (
				!$myAmbiente ||
				empty($myAmbiente) ||
				!Validate::isGenericName($myAmbiente)
			) {
				$output .= $this->displayError('Ambiente es requerido');
			} else {
				Configuration::updateValue('ApiKey', $myModuleName);
				Configuration::updateValue('Password', $myPassword);
				Configuration::updateValue('Ambiente', $myAmbiente);
				$output .= $this->displayConfirmation('Configuraci&oacute;n actualizada');
			}
		}

		return $output.$this->displayForm();
    }

public function displayForm()
{
    // Get default language
    $defaultLang = (int)Configuration::get('PS_LANG_DEFAULT');

    // Init Fields form array
    $fieldsForm[0]['form'] = [
        'legend' => [
            'title' => 'Configuraci&oacute;n',
        ],
        'input' => [
			[
				'type' => 'select',
				'label' => 'Ambiente',
				'name' => 'Ambiente',
				'multiple' => false,
				'options' => [
					'query' => [
						['key' => '1', 'name' => 'Sandbox'],
						['key' => '2', 'name' => 'Producci&oacute;n']
					],
					'id' => 'key',
					'name' => 'name'
				]
			],
			[
                'type' => 'text',
                'label' => 'ApiKey',
                'name' => 'ApiKey',
                'size' => 20,
                'required' => true
            ],
            [
                'type' => 'text',
                'label' => 'Password',
                'name' => 'Password',
                'size' => 20,
                'required' => true
            ]
        ],
        'submit' => [
            'title' => $this->l('Save'),
            'class' => 'btn btn-default pull-right'
        ]
    ];

    $helper = new HelperForm();

    // Module, token and currentIndex
    $helper->module = $this;
    $helper->name_controller = $this->name;
    $helper->token = Tools::getAdminTokenLite('AdminModules');
    $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

    // Language
    $helper->default_form_language = $defaultLang;
    $helper->allow_employee_form_lang = $defaultLang;

    // Title and toolbar
    $helper->title = $this->displayName;
    $helper->show_toolbar = true;        // false -> remove toolbar
    $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
    $helper->submit_action = 'submit'.$this->name;
    $helper->toolbar_btn = [
        'save' => [
            'desc' => $this->l('Save'),
            'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
            '&token='.Tools::getAdminTokenLite('AdminModules'),
        ],
        'back' => [
            'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
            'desc' => $this->l('Back to list')
        ]
    ];

    // Load current value
    $helper->fields_value['ApiKey'] = Tools::getValue('ApiKey', Configuration::get('ApiKey'));
	$helper->fields_value['Password'] = Tools::getValue('Password', Configuration::get('Password'));
	$helper->fields_value['Ambiente'] = Tools::getValue('Ambiente', Configuration::get('Ambiente'));

    return $helper->generateForm($fieldsForm);
}

}